<?php
// MongoDB Database CONFIG WIZARD
//
// Copyright (c) 2013 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: $

include_once(dirname(__FILE__).'/../configwizardhelper.inc.php');

// run the initialization function
mongodb_database_configwizard_init();

function mongodb_database_configwizard_init()
{
    $name="mongodb_database";
    
    $args=array(
        CONFIGWIZARD_NAME => $name,
        CONFIGWIZARD_VERSION => "1.0",
        CONFIGWIZARD_TYPE => CONFIGWIZARD_TYPE_MONITORING,
        CONFIGWIZARD_DESCRIPTION => gettext("Monitor a MongoDB Database"),
        CONFIGWIZARD_DISPLAYTITLE => gettext("MongoDB Database"),
        CONFIGWIZARD_FUNCTION => "mongodb_database_configwizard_func",
        CONFIGWIZARD_PREVIEWIMAGE => "mongodb_db.png",
        );
        
    register_configwizard($name,$args);
}

function mongodb_database_configwizard_check_prereqs()
{
    // plugin doesn't exist
    if(!file_exists("/usr/local/nagios/libexec/check_mongodb.py")){
        return false;
    }
        
    // run the plugin to see if pymongo is installed
    $retval=0;
    $cmdline="/usr/local/nagios/libexec/check_mongodb.py | head --lines=1";
    $output=exec($cmdline);
    
    if(strstr($output,"No module named pymongo"))
        return false;

    return true;
}

function mongodb_database_configwizard_func($mode="",$inargs=null,&$outargs,&$result)
{
    $wizard_name="mongodb_database";
    
    // initialize return code and output
    $result=0;
    $output="";
    
    // initialize output args - pass back the same data we got
    $outargs[CONFIGWIZARD_PASSBACK_DATA]=$inargs;

    switch($mode){
        case CONFIGWIZARD_MODE_GETSTAGE1HTML:

            if(mongodb_database_configwizard_check_prereqs()==false)
            {
        
                $output.='<p><b>'.gettext('Error').':</b> '.gettext('It looks like you are missing pymongo on your Nagios XI server.').'</p><p>'.gettext('To use this wizard you must install pymongo on your server. If you are using CentOS or RHEL you can run "yum install pymongo".').'</p>';
            }
            else
            {
        
                $address=grab_array_var($inargs,"address","");
                $port=grab_array_var($inargs,"port","27017");
                $username=grab_array_var($inargs,"username","");
                $password=grab_array_var($inargs,"password","");
                $database=grab_array_var($inargs,"database","test");
                
				if(!empty($services_serial))
					$services=unserialize(base64_decode($services_serial));
				$serviceargs_serial=grab_array_var($inargs,"serviceargs_serial");
				if(!empty($serviceargs_serial)){
					$serviceargs=unserialize(base64_decode($serviceargs_serial));
				}
				
                $output='
				
    <div class="sectionTitle">'.gettext('MongoDB Information').'</div>
    
    <p>
    '.gettext('Specify the details for connecting to the MongoDB database you want to monitor').'.
    </p>
            
    <table>

    <tr>
    <td valign="top">
    <label>'.gettext('Address').':</label><br class="nobr" />
    </td>
    <td>
<input type="text" size="40" name="address" id="address" value="'.htmlentities($address).'" class="textfield" /><br class="nobr" />
    '.gettext('The IP address or FQDNS name of the MongoDB server').'.<br><br>
    </td>
    </tr>   

    <tr>
    <td valign="top">
    <label>'.gettext('Port').':</label><br class="nobr" />
    </td>
    <td>
<input type="text" size="5" name="port" id="port" value="'.htmlentities($port).'" class="textfield" /><br class="nobr" />
    '.gettext('The port to use to connect to the MongoDB server. This defaults to port 27017, however if you changed the port number enter it here').'.<br /><br />
    </td>
    </tr>

    <tr>
    <td valign="top">
    <label>'.gettext('Username').':</label><br class="nobr" />
    </td>
    <td>
<input type="text" size="40" name="username" id="username" value="'.htmlentities($username).'" class="textfield" /><br class="nobr" />
    '.gettext('The username used to connect to the database').'.<br><br>
    </td>
    </tr> 

    <tr>
    <td valign="top">
    <label>'.gettext('Password').':</label><br class="nobr" />
    </td>
    <td>
<input type="password" size="40" name="password" id="password" value="'.htmlentities($password).'" class="textfield" /><br class="nobr" />
    '.gettext('The password for the above user').'.<br><br>
    </td>
    </tr> 

    <tr>
    <td valign="top">
    <label>'.gettext('Database').':</label><br class="nobr" />
    </td>
    <td>
<input type="text" size="40" name="database" id="database" value="'.htmlentities($database).'" class="textfield" /><br class="nobr" />
    '.gettext('The database you want to monitor').'.<br><br>
    </td>
    </tr>

    </table>

            ';
            }
            break;
            
        case CONFIGWIZARD_MODE_VALIDATESTAGE1DATA:
        
            // get variables that were passed to us
            $address=grab_array_var($inargs,"address","");
            $hostname=grab_array_var($inargs,"hostname");
            $port=grab_array_var($inargs,"port","27017");
            $username=grab_array_var($inargs,"username","");
            $password=grab_array_var($inargs,"password","");
            $database=grab_array_var($inargs,"database","test");
            
            // check for errors
            $errors=0;
            $errmsg=array();
            if(have_value($address)==false)
                $errmsg[$errors++]="No address specified.";
            if(have_value($username)==false)
                $errmsg[$errors++]="No username specified.";
            if(have_value($password)==false)
                $errmsg[$errors++]="No password specified.";
            if(have_value($database)==false)
                $errmsg[$errors++]="No database specified.";

            if($errors>0){
                $outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
                $result=1;
            }
                
            break;
            
        case CONFIGWIZARD_MODE_GETSTAGE2HTML:
        
            // get variables that were passed to us
            $address=grab_array_var($inargs,"address","");
            $hostname=grab_array_var($inargs,"hostname");
            $port=grab_array_var($inargs,"port","27017");
            $username=grab_array_var($inargs,"username","");
            $password=grab_array_var($inargs,"password","");
            $database=grab_array_var($inargs,"database","test");

            $ha=@gethostbyaddr($address);
            if($ha=="")
                $ha=$address;
            $hostname=grab_array_var($inargs,"hostname",$ha);
            
            $services=grab_array_var($inargs,"services",array(
                "collections"=>"on",
                "objects"=>"on",
                "database_size"=>"on"
                ));
            $serviceargs=grab_array_var($inargs,"serviceargs",array(
                "collections_warning"=>"50",
                "collections_critical"=>"200",
                "objects_warning"=>"200",
                "objects_critical"=>"1000",
                "database_size_warning"=>"33554432", // 32 MB
                "database_size_critical"=>"67108864" // 64 MB
                ));
            
            // Replace defaults with the given values
            $services_serial=grab_array_var($inargs,"services_serial");
            if(!empty($services_serial))
                $services=unserialize(base64_decode($services_serial));
            $serviceargs_serial=grab_array_var($inargs,"serviceargs_serial");
            if(!empty($serviceargs_serial)){
                $serviceargs=unserialize(base64_decode($serviceargs_serial));
            }
        
            $output='
            
        <input type="hidden" name="address" value="'.htmlentities($address).'" />
        <input type="hidden" name="port" value="'.htmlentities($port).'" />
		<input type="hidden" name="username" value="'.htmlentities($username).'" />
		<input type="hidden" name="password" value="'.htmlentities($password).'" />
		<input type="hidden" name="database" value="'.htmlentities($database).'" />
    
    <div class="sectionTitle">'.gettext('MongoDB Information').'</div>
            
    <table>
    
    <tr>
    <td valign="top">
    <label>'.gettext('Address').':</label><br class="nobr" />
    </td>
    <td>
<input type="text" size="20" name="address" id="address" value="'.htmlentities($address).'" class="textfield" disabled/><br class="nobr" />
    </td>
    </tr>

    <tr>
    <td valign="top">
    <label>'.gettext('Host Name').':</label><br class="nobr" />
    </td>
    <td>
<input type="text" size="20" name="hostname" id="hostname" value="'.htmlentities($hostname).'" class="textfield" /><br class="nobr" />
    '.gettext('The name you\'d like to have associated with this MongoDB Database').'.
    </td>
    </tr>
    
    <tr>
    <td valign="top">
    <label>'.gettext('Port').':</label><br class="nobr" />
    </td>
    <td>
<input type="text" size="5" name="port" id="port" value="'.htmlentities($port).'" class="textfield" disabled/><br class="nobr" />
    </td>
    </tr>

    <tr>
    <td valign="top">
    <label>'.gettext('Username').':</label><br class="nobr" />
    </td>
    <td>
<input type="text" size="20" name="username" id="username" value="'.htmlentities($username).'" class="textfield" disabled/><br class="nobr" />
    </td>
    </tr>

    <tr>
    <td valign="top">
    <label>'.gettext('Database').':</label><br class="nobr" />
    </td>
    <td>
<input type="text" size="20" name="database" id="database" value="'.htmlentities($database).'" class="textfield" disabled/><br class="nobr" />
    </td>
    </tr>

    </table>

    <div class="sectionTitle">'.gettext('MongoDB Database Metrics').'</div>
    
    <p>'.gettext('Specify the metrics you\'d like to monitor on the MongoDB database').'.</p>
    
    <table>
    
    <tr>
    <td valign="top">
    <input type="checkbox" class="checkbox" name="services[collections]" '.is_checked(grab_array_var($services,"collections"),"on").'>
    </td>
    <td>
    <b>'.gettext('Number of Collections').'</b><br> 
    '.gettext('Monitor the number of collections in the database').'.<br>
    <label>'.gettext('Warning Threshold').':</label> <input type="text" size="1" name="serviceargs[collections_warning]" value="'.htmlentities($serviceargs["collections_warning"]).'">&nbsp;&nbsp;<label>'.gettext('Critical Threshold').':</label> <input type="text" size="1" name="serviceargs[collections_critical]" value="'.htmlentities($serviceargs["collections_critical"]).'"><br><br>
    </td>
    </tr>

    <tr>
    <td valign="top">
    <input type="checkbox" class="checkbox" name="services[objects]" '.is_checked(grab_array_var($services,"objects"),"on").'>
    </td>
    <td>
    <b>'.gettext('Number of Objects').'</b><br> 
    '.gettext('Monitor the number of objects (documents) in the database').'.<br>
    <label>'.gettext('Warning Threshold').':</label> <input type="text" size="1" name="serviceargs[objects_warning]" value="'.htmlentities($serviceargs["objects_warning"]).'">&nbsp;&nbsp;<label>'.gettext('Critical Threshold').':</label> <input type="text" size="1" name="serviceargs[objects_critical]" value="'.htmlentities($serviceargs["objects_critical"]).'"><br><br>
    </td>
    </tr>

    <tr>
    <td valign="top">
    <input type="checkbox" class="checkbox" name="services[database_size]" '.is_checked(grab_array_var($services,"database_size"),"on").'>
    </td>
    <td>
    <b>'.gettext('Database Size').'</b><br> 
    '.gettext('Monitor the size of the database in bytes').'.<br>
    <label>'.gettext('Warning Threshold').':</label> <input type="text" size="1" name="serviceargs[database_size_warning]" value="'.htmlentities($serviceargs["database_size_warning"]).'">&nbsp;&nbsp;<label>'.gettext('Critical Threshold').':</label> <input type="text" size="1" name="serviceargs[database_size_critical]" value="'.htmlentities($serviceargs["database_size_critical"]).'"><br><br>
    </td>
    </tr>

    </table>
    ';
            break;
            
        case CONFIGWIZARD_MODE_VALIDATESTAGE2DATA:
        
            // get variables that were passed to us
            $address=grab_array_var($inargs,"address","");
            $hostname=grab_array_var($inargs,"hostname");
            $port=grab_array_var($inargs,"port","27017");
            $username=grab_array_var($inargs,"username","");
            $password=grab_array_var($inargs,"password","");
            $database=grab_array_var($inargs,"database","test");
                
            $services=grab_array_var($inargs,"services",array());
            $serviceargs=grab_array_var($inargs,"serviceargs",array());
            
        
            // check for errors
            $errors=0;
            $errmsg=array();
            if(is_valid_host_name($hostname)==false)
                $errmsg[$errors++]="Invalid host name.";
                
            if($errors>0){
                $outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
                $result=1;
                }
                
            break;

            
        case CONFIGWIZARD_MODE_GETSTAGE3HTML:
        
            // get variables that were passed to us
            $address=grab_array_var($inargs,"address","");
            $hostname=grab_array_var($inargs,"hostname");
            $port=grab_array_var($inargs,"port","27017");
            $username=grab_array_var($inargs,"username","");
            $password=grab_array_var($inargs,"password","");
            $database=grab_array_var($inargs,"database","test");
            
            $services=grab_array_var($inargs,"services",array());
            if (empty($services)) {
                $services_serial = grab_array_var($inargs,"services_serial");
            } else {
                $services_serial = base64_encode(serialize($services));
            }
            $serviceargs=grab_array_var($inargs,"serviceargs",array());
            if (empty($serviceargs)) {
                $serviceargs_serial = grab_array_var($inargs,"serviceargs_serial");
            } else {
                $serviceargs_serial = base64_encode(serialize($serviceargs));
            }
        
            $output='
            
                <input type="hidden" name="address" value="'.htmlentities($address).'" />
                <input type="hidden" name="hostname" value="'.htmlentities($hostname).'" />
                <input type="hidden" name="port" value="'.htmlentities($port).'" />
                <input type="hidden" name="username" value="'.htmlentities($username).'" />
                <input type="hidden" name="password" value="'.htmlentities($password).'" />
                <input type="hidden" name="database" value="'.htmlentities($database).'" />
                <input type="hidden" name="services_serial" value="'.$services_serial.'" />
                <input type="hidden" name="serviceargs_serial" value="'.$serviceargs_serial.'" />
        
            ';
            break;
            
        case CONFIGWIZARD_MODE_VALIDATESTAGE3DATA:
                
            break;
            
        case CONFIGWIZARD_MODE_GETFINALSTAGEHTML:
            
            // get variables that were passed to us
            $address=grab_array_var($inargs,"address","");
            $hostname=grab_array_var($inargs,"hostname");
            $port=grab_array_var($inargs,"port","27017");
            $username=grab_array_var($inargs,"username","");
            $password=grab_array_var($inargs,"password","");
            $database=grab_array_var($inargs,"database","test");
            
            $services=grab_array_var($inargs,"services",array());
            if (empty($services)) {
                $services_serial = grab_array_var($inargs,"services_serial");
            } else {
                $services_serial = base64_encode(serialize($services));
            }
            $serviceargs=grab_array_var($inargs,"serviceargs",array());
            if (empty($serviceargs)) {
                $serviceargs_serial = grab_array_var($inargs,"serviceargs_serial");
            } else {
                $serviceargs_serial = base64_encode(serialize($serviceargs));
            }
        
            $output='
            
                <input type="hidden" name="address" value="'.htmlentities($address).'" />
                <input type="hidden" name="hostname" value="'.htmlentities($hostname).'" />
                <input type="hidden" name="port" value="'.htmlentities($port).'" />
                <input type="hidden" name="username" value="'.htmlentities($username).'" />
                <input type="hidden" name="password" value="'.htmlentities($password).'" />
                <input type="hidden" name="database" value="'.htmlentities($database).'" />
                <input type="hidden" name="services_serial" value="'.$services_serial.'" />
                <input type="hidden" name="serviceargs_serial" value="'.$serviceargs_serial.'" />
        
            ';
            break;
            
        case CONFIGWIZARD_MODE_GETOBJECTS:
        
            // Get the vars
            $address=grab_array_var($inargs,"address");
            $hostname=grab_array_var($inargs,"hostname");
            $port=grab_array_var($inargs,"port");
            $username=grab_array_var($inargs,"username");
            $password=grab_array_var($inargs,"password");
            $database=grab_array_var($inargs,"database");
        
            $services_serial=grab_array_var($inargs,"services_serial","");
            $serviceargs_serial=grab_array_var($inargs,"serviceargs_serial","");
            
            $services=unserialize(base64_decode($services_serial));
            $serviceargs=unserialize(base64_decode($serviceargs_serial));

            // save data for later use in re-entrance
            $meta_arr=array();
            $meta_arr["hostname"]=$hostname;
            $meta_arr["address"]=$address;
            $meta_arr["port"]=$port;
            $meta_arr["database"]=$database;
            $meta_arr["username"]=$username;
            $meta_arr["services"]=$services;
            $meta_arr["serviceargs"]=$serviceargs;
            save_configwizard_object_meta($wizard_name,$hostname,"",$meta_arr);
            
            $objs=array();
            
            if(!host_exists($hostname)){
                $objs[]=array(
                    "type" => OBJECTTYPE_HOST,
                    "use" => "xiwizard_mongodbdatabase_host",
                    "host_name" => $hostname,
                    "address" => $address,
                    "icon_image" => "mongodb.png",
                    "statusmap_image" => "mongodb.png",
                    "_xiwizard" => $wizard_name,
                    );
                }

            foreach($services as $svcvar => $svcval){
            
                switch($svcvar){
                                
                    case "collections":
                        $objs[]=array(
                            "type" => OBJECTTYPE_SERVICE,
                            "host_name" => $hostname,
                            "service_description" => "MongoDB Database Collections",
                            "use" => "xiwizard_mongodbdatabase_service",
                            "check_command" => "check_mongodb_database!collections!".$port."!".$serviceargs["collections_warning"]."!".$serviceargs["collections_critical"]."!".$username."!".$password."!".$database,
                            "_xiwizard" => $wizard_name,
                            );
                        break;
                                
                    case "objects":
                        $objs[]=array(
                            "type" => OBJECTTYPE_SERVICE,
                            "host_name" => $hostname,
                            "service_description" => "MongoDB Database Objects",
                            "use" => "xiwizard_mongodbdatabase_service",
                            "check_command" => "check_mongodb_database!objects!".$port."!".$serviceargs["objects_warning"]."!".$serviceargs["objects_critical"]."!".$username."!".$password."!".$database,
                            "_xiwizard" => $wizard_name,
                            );
                        break;

                    case "database_size":
                        $objs[]=array(
                            "type" => OBJECTTYPE_SERVICE,
                            "host_name" => $hostname,
                            "service_description" => "MongoDB Database Size",
                            "use" => "xiwizard_mongodbdatabase_service",
                            "check_command" => "check_mongodb_database!database_size!".$port."!".$serviceargs["database_size_warning"]."!".$serviceargs["database_size_critical"]."!".$username."!".$password."!".$database,
                            "_xiwizard" => $wizard_name,
                            );
                        break;

                    default:
                        break;
                    }
                }

            // return the object definitions to the wizard
            $outargs[CONFIGWIZARD_NAGIOS_OBJECTS]=$objs;
        
            break;

        default:
            break;          
        }

    return $output;
}
?>
