<?php
//
// Copyright (c) 2008-2009 Nagios Enterprises, LLC.  All rights reserved.
//
// $Id: coreconfigsnapshots.php 2806 2014-07-11 15:57:43Z swilkerson $

require_once(dirname(__FILE__) . '/../includes/common.inc.php');

// initialization stuff
pre_init();

// start session
init_session();

// grab GET or POST variables 
grab_request_vars();

// check prereqs
check_prereqs();

// check authentication
check_authentication(false);

// only admins can access this page
if (is_admin() == false) {
    echo $lstr['NotAuthorizedErrorText'];
    exit();
}

// route request
route_request();


function route_request()
{
    global $request;

//	if(in_demo_mode()==true)
    //	header("Location: main.php");

    if (isset($request["download"]))
        do_download();
    else if (isset($request["view"]))
        do_view();
    else if (isset($request["delete"]))
        do_delete();
    else if (isset($request["doarchive"]))
        do_archive();
    else if (isset($request["restore"]))
        do_restore();
    else if (isset($request["rename"]))
        do_rename();
    else
        show_log();

    exit;
}


/**
 * @param bool   $error
 * @param string $msg
 */
function show_log($error = false, $msg = "")
{
    global $lstr;


    $snapshots = get_nagioscore_config_snapshots();


    do_page_start(array("page_title" => $lstr['CoreConfigSnapshotsPageTitle']), true);

    ?>


    <h1><?php echo $lstr['CoreConfigSnapshotsPageHeader']; ?></h1>


    <?php
    display_message($error, false, $msg);
    ?>

    <?php echo $lstr['CoreConfigSnapshotsPageNotes']; ?>

    <br><br>

    <?php //print_r($snapshots) ?>

    <script type="text/javascript">
        function verify() {
            var answer = confirm("Are you sure you want to restore the NagiosQL database?");
            if (answer) {
                $("#childcontentthrobber").css("visibility", "visible");
                return true;
            }
            return false;
        }

        function verify_delete_archive() {
            var conf = confirm('<?php echo gettext("Are you sure you want to permanently delete this archived Configuration Snapshot?");?>');
            if (conf) {
                $("#childcontentthrobber").css("visibility", "visible");
                return true;
            }
            return false;
        }
    </script>

    <table class="standardtable">
        <thead>
        <tr>
            <th><?php echo $lstr['DateTableHeader']; ?></th>
            <th><?php echo $lstr['SnapshotResultTableHeader']; ?></th>
            <th><?php echo $lstr['FileTableHeader']; ?></th>
            <th><?php echo $lstr['ActionsTableHeader']; ?></th>
        </tr>
        </thead>
        <tbody>

        <?php
        $x = 0;
        $archives = 0;
        foreach ($snapshots as $snapshot) {

            if ($snapshot["archive"]) {
                $archives++;
                continue;
            }
            $x++;

            $resultstring = "Config Ok";
            $rowclass = "";
            $qstring = "result=ok&archive=0";
            if ($snapshot["error"] == true) {
                $resultstring = "Config Error";
                $rowclass = "alert";
                $qstring = "result=error&archive=0";
            }

            if (($x % 2) != 0)
                $rowclass .= " odd";
            else
                $rowclass .= " even";

            echo "<tr class=" . $rowclass . ">";
            echo "<td>" . $snapshot["date"] . "</td>";
            echo "<td>" . $resultstring . "</td>";
            echo "<td>" . $snapshot["file"] . "</td>";
            echo "<td>";
            echo "<a href='?download=" . $snapshot["timestamp"] . "&" . $qstring . "'><img src='" . theme_image("download.png") . "' alt='" . $lstr['DownloadAlt'] . "' title='" . $lstr['DownloadAlt'] . "'></a> ";
            echo "<a href='?view=" . $snapshot["timestamp"] . "&" . $qstring . "'><img src='" . theme_image("detail.png") . "' alt='" . $lstr['ViewOutputAlt'] . "' title='" . $lstr['ViewOutputAlt'] . "'></a> ";
            if ($snapshot["error"] == true) {
                echo "<a href='?delete=" . $snapshot["timestamp"] . "&" . $qstring . "'><img src='" . theme_image("delete.png") . "' alt='" . $lstr['DeleteAlt'] . "' title='" . $lstr['DeleteAlt'] . "'></a> ";
            } else {
                if (use_2012_features() == true)
                    echo "<a href='?restore=" . $snapshot["timestamp"] . "&" . $qstring . "'><img src='" . theme_image("reload.png") . "' alt='" . $lstr['RestoreAlt'] . "' title='" . $lstr['RestoreAlt'] . "'  onclick='return verify();'></a> ";
                if (use_2014_features() == true)
                    echo "<a href='?doarchive=" . $snapshot["timestamp"] . "&" . $qstring . "'><img src='" . theme_image("history.png") . "' alt='" . gettext('Archive') . "' title='" . gettext('Archive') . "'></a>";
            }
            echo "</td>";
            echo "</tr>\n";
        }
        ?>

        </tbody>
    </table>
    <br/><br/>

    <?php
    if ($archives > 0) {
        ?>
        <h3><?php echo gettext("Archived Snapshots"); ?></h3>
        <table class="standardtable">
            <thead>
            <tr>
                <th><?php echo $lstr['DateTableHeader']; ?></th>
                <th><?php echo $lstr['SnapshotResultTableHeader']; ?></th>
                <th><?php echo $lstr['FileTableHeader']; ?></th>
                <th><?php echo $lstr['ActionsTableHeader']; ?></th>
            </tr>
            </thead>
            <tbody>

            <?php
            $x = 0;
            foreach ($snapshots as $snapshot) {

                if ($snapshot["archive"] == false)
                    continue;

                $x++;

                $resultstring = "Config Ok";
                $rowclass = "";
                $qstring = "result=ok&archive=1";
                if ($snapshot["error"] == true) {
                    $resultstring = "Config Error";
                    $rowclass = "alert";
                    $qstring = "result=error&archive=1";
                }

                if (($x % 2) != 0)
                    $rowclass .= " odd";
                else
                    $rowclass .= " even";

                echo "<tr class=" . $rowclass . ">";
                echo "<td>" . $snapshot["date"] . "</td>";
                echo "<td>" . $resultstring . "</td>";
                echo "<td>" . $snapshot["file"] . "</td>";
                echo "<td>";

                // Remove the ending of filename
                $filename = str_replace(".tar.gz", "", $snapshot['file']);

                // Rename
                echo "<a href='?rename=" . $snapshot["timestamp"] . "&file=" . $filename . "&" . $qstring . "'><img src='" . theme_image("editfile.png") . "' alt='" . gettext('Rename') . "' title='" . gettext('Rename') . "'></a> ";

                echo "<a href='?download=" . $filename . "&" . $qstring . "'><img src='" . theme_image("download.png") . "' alt='" . $lstr['DownloadAlt'] . "' title='" . $lstr['DownloadAlt'] . "'></a> ";
                echo "<a href='?view=" . $filename . "&" . $qstring . "'><img src='" . theme_image("detail.png") . "' alt='" . $lstr['ViewOutputAlt'] . "' title='" . $lstr['ViewOutputAlt'] . "'></a> ";
                echo "<a href='?delete=" . $filename . "&" . $qstring . "'><img src='" . theme_image("delete.png") . "' alt='" . $lstr['DeleteAlt'] . "' title='" . $lstr['DeleteAlt'] . "' onclick='return verify_delete_archive();'></a> ";
                if (use_2012_features() == true)
                    echo "<a href='?restore=" . $filename . "&" . $qstring . "'><img src='" . theme_image("reload.png") . "' alt='" . $lstr['RestoreAlt'] . "' title='" . $lstr['RestoreAlt'] . "'  onclick='return verify();'></a>";
            }
            echo "</td>";
            echo "</tr>\n";
            ?>

            </tbody>
        </table>

        <form method="post" action="" id="rename_form">
            <input type="hidden" name="">
        </form>

    <?php

    } //end if ($archives>0)

    do_page_end(true);
    exit();
}

function do_download()
{
    global $cfg;

    $result = grab_request_var("result", "ok");
    $ts = grab_request_var("download", "");
    $archive = grab_request_var("archive", 0);

    // base checkpoints dir
    $dir = $cfg['nom_checkpoints_dir'];
    if ($archive == "1")
        $dir .= "archives/";
    if ($result == "error")
        $dir .= "errors/";

    // clean the timestamp
    $ts = str_replace("..", "", $ts);
    $ts = str_replace("/", "", $ts);
    $ts = str_replace("\\", "", $ts);

    $thefile = $dir . $ts . ".tar.gz";

    header('Content-type: application/x-gzip');
    header("Content-length: " . filesize($thefile));
    header('Content-Disposition: attachment; filename="' . basename($thefile) . '"');
    readfile($thefile);
    exit();
}

function do_view()
{
    global $cfg;

    $result = grab_request_var("result", "ok");
    $ts = grab_request_var("view", "");
    $archive = grab_request_var("archive", 0);

    // base checkpoints dir
    $dir = $cfg['nom_checkpoints_dir'];
    if ($archive == "1")
        $dir .= "archives/";
    if ($result == "error")
        $dir .= "errors/";

    // clean the timestamp
    $ts = str_replace("..", "", $ts);
    $ts = str_replace("/", "", $ts);
    $ts = str_replace("\\", "", $ts);

    $thefile = $dir . $ts . ".txt";

    header('Content-type: application/text');
    header("Content-length: " . filesize($thefile));
    header('Content-Disposition: attachment; filename="' . basename($thefile) . '"');
    readfile($thefile);
    exit();
}

function do_delete()
{
    global $lstr;

    // demo mode
    if (in_demo_mode() == true)
        show_log(true, $lstr['DemoModeChangeError']);

    $ts = grab_request_var("delete", "");
    $archived = grab_request_var("archive", 0);


    // log it
    send_to_audit_log("User deleted core config snapsnot '" . $ts . "'", AUDITLOGTYPE_DELETE);

    // clean the filename
    $ts = str_replace("..", "", $ts);
    $ts = str_replace("/", "", $ts);
    $ts = str_replace("\\", "", $ts);

    if ($ts == "")
        show_log();

    // Allow archived snapshot deletion
    if ($archived) {
        $id = submit_command(COMMAND_DELETE_ARCHIVE_SNAPSHOT, $ts);
    } else {
        $id = submit_command(COMMAND_DELETE_CONFIGSNAPSHOT, $ts);
    }

    if ($id <= 0)
        show_log(true, $lstr['ErrorSubmittingCommandText']);
    else {
        for ($x = 0; $x < 14; $x++) {
            $status_code = -1;
            $args = array(
                "cmd" => "getcommands",
                "command_id" => $id,
            );
            $xml = get_backend_xml_data($args);
            if ($xml) {
                if ($xml->command[0]) {
                    $status_code = intval($xml->command[0]->status_code);
                }
            }
            if ($status_code == 2) {
                show_log(false, $lstr['ConfigSnapshotDeletedText']);
                exit();
            }
            usleep(500000);
        }
    }
    show_log(false, $lstr['ConfigSnapshotScheduledForDeletionText']);
    exit();
}

function do_archive()
{
    global $lstr;

    // demo mode
    if (in_demo_mode() == true)
        show_log(true, $lstr['DemoModeChangeError']);

    $ts = grab_request_var("doarchive", "");


    // log it
    send_to_audit_log("User archived core config snapsnot '" . $ts . "'", AUDITLOGTYPE_DELETE);

    // clean the filename
    $ts = str_replace("..", "", $ts);
    $ts = str_replace("/", "", $ts);
    $ts = str_replace("\\", "", $ts);

    if ($ts == "")
        show_log();

    $id = submit_command(COMMAND_ARCHIVE_SNAPSHOT, $ts);
    if ($id <= 0)
        show_log(true, $lstr['ErrorSubmittingCommandText']);
    else {
        for ($x = 0; $x < 14; $x++) {
            $status_code = -1;
            $args = array(
                "cmd" => "getcommands",
                "command_id" => $id,
            );
            $xml = get_backend_xml_data($args);
            if ($xml) {
                if ($xml->command[0]) {
                    $status_code = intval($xml->command[0]->status_code);
                }
            }
            if ($status_code == 2) {
                show_log(false, gettext('Snapshot archived'));
                exit();
            }
            usleep(500000);
        }
    }
    show_log(false, gettext('Snapshot scheduled for archiving'));
    exit();
}

function do_restore()
{
    global $cfg;
    global $lstr;

    // demo mode
    if (in_demo_mode() == true)
        show_log(true, $lstr['DemoModeChangeError']);

    $ts = grab_request_var("restore", "");
    $archive = grab_request_var("archive", 0);

    $baseurl = get_base_url();
    // log it
    send_to_audit_log("User restored system to config snapsnot '" . $ts . "'", AUDITLOGTYPE_CHANGE);

    // clean the filename
    $ts = str_replace("..", "", $ts);
    $ts = str_replace("/", "", $ts);
    $ts = str_replace("\\", "", $ts);

    if ($ts == "")
        show_log();

    if ($archive == 1)
        $dir = $cfg['nom_checkpoints_dir'] . '/../nagiosxi/archives';
    else
        $dir = $cfg['nom_checkpoints_dir'] . '/../nagiosxi';

    if (!file_exists($dir . "/" . $ts . "_nagiosql.sql.gz")) {
        show_log(true, "This snapshot doesn't exist");
        exit();
    }

    if ($archive == 1)
        $id = submit_command(COMMAND_RESTORE_NAGIOSQL_SNAPSHOT, $ts . " restore archives");
    else
        $id = submit_command(COMMAND_RESTORE_NAGIOSQL_SNAPSHOT, $ts . " restore");

    if ($id <= 0)
        show_log(true, $lstr['ErrorSubmittingCommandText']);
    else {
        for ($x = 0; $x < 14; $x++) {
            $status_code = -1;
            $args = array(
                "cmd" => "getcommands",
                "command_id" => $id,
            );
            $xml = get_backend_xml_data($args);
            if ($xml) {
                if ($xml->command[0]) {
                    $status_code = intval($xml->command[0]->status_code);
                }
            }
            if ($status_code == 2) {
                show_log(false, "NagiosQL Snapshot Restored.</br><strong><a href='" . nagioscorecfg_get_component_url(true) . "applyconfig.php?cmd=confirm'>" . $lstr['ApplyConfigText'] . "</a></strong> &nbsp;<a href='" . $baseurl . "includes/components/ccm/xi-index.php' target='_top'>View Config</a>");
                exit();
            }
            usleep(500000);
        }
    }
    show_log(false, $lstr['ConfigSnapshotScheduledForRestoreText']);
    exit();
}

#
# RENAME AN ARCHIVED CONFIG SNAPSHOT
#
function do_rename()
{
    global $lstr;

    $ts = grab_request_var("rename", "");
    $file = grab_request_var("file", "");
    $new_name = grab_request_var("new_name", "");
    $cancel = grab_request_var("cancel", 0);

    if ($ts == '' || $file == '' || $cancel)
        show_log();

    if (!$new_name) {

        //
        // DISPLAY RENAME FORM
        //

        do_page_start(array("page_title" => $lstr['CoreConfigSnapshotsPageTitle']), true);

        echo "<h1>" . $lstr['CoreConfigSnapshotsPageHeader'] . "</h1>";
        echo '<p>' . gettext('Rename an archived configuration snapshot. Archived snapshots must have no spaces in their names.') . '</p>';

        ?>
        <table class="standardtable">
            <thead>
            <tr>
                <th><?php echo $lstr['DateTableHeader']; ?></th>
                <th><?php echo $lstr['FileTableHeader']; ?></th>
            </tr>
            </thead>
            <tbody>
            <tr>
                <td><?php echo date("Y-m-d H:i:s", $ts); ?></td>
                <td><?php echo $file . ".tar.gz"; ?></td>
            </tr>
            </tbody>
        </table>
        <?php
        echo '<h3>Rename Snapshot To</h3>';
        echo '<form method="post">';
        echo '<p><input type="text" name="new_name"> .' . $ts . '.tar.gz</p>';

        echo '<button type="submit">Rename</button><button type="submit" name="cancel" value="1">Cancel</button>';
        echo '</form>';

        do_page_end(true);

    } else {

        //
        // RENAME THE ARCHIVED SNAPSHOT
        //

        // Actually set the name!
        $command_data = array();
        $command_data[0] = str_replace(".tar.gz", "", $file);
        $command_data[1] = $new_name . "." . $ts;
        $command_data = serialize($command_data);

        // Send command to the subsystem
        $id = submit_command(COMMAND_RENAME_ARCHIVE_SNAPSHOT, $command_data);

        if ($id <= 0)
            show_log(true, $lstr['ErrorSubmittingCommandText']);
        else {
            for ($x = 0; $x < 14; $x++) {
                $status_code = -1;
                $args = array(
                    "cmd" => "getcommands",
                    "command_id" => $id,
                );
                $xml = get_backend_xml_data($args);
                if ($xml) {
                    if ($xml->command[0]) {
                        $status_code = intval($xml->command[0]->status_code);
                    }
                }
                if ($status_code == 2) {
                    show_log(false, gettext("Snapshot has been renamed."));
                    exit();
                }
                usleep(500000);
            }
        }
        show_log(false, gettext("Snapshot scheduled to be renamed."));
        exit();
    }
}

?>